Skip to contents

Stops containers started by runStudy() and/or runRStudio(). By default it stops containers for the image inferred from the current directory name.

Usage

stopStudy(
  container = NULL,
  image_name = NULL,
  mode = c("any", "rstudio", "run"),
  all = FALSE
)

Arguments

container

Optional container name or ID to stop directly.

image_name

Optional Docker image name. Defaults to current directory name.

mode

Which container(s) to stop: "any" (default), "rstudio", or "run".

all

If TRUE, stops all running containers started by OmopStudyBuilder.

Value

TRUE if at least one container was stopped (invisibly)